@@ -1,6 +1,6 @@
-GOOF----LE-8-2.0Z      ]  4      h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  
+GOOF----LE-4-2.0Y      ]  4      h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  
 net-linechart	
-	 	g  filenameS	f  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm	
+	 	g  filenameS	f  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm	
 g  set-current-module	
  	
  	g  process-use-modules	 	 	g  srfi	g  srfi-1	 	 	g  main	 	 	g  
@@ -19,27 +19,27 @@ gnc:timepair? g  throw g  wrong g  gnc-numeric-to-double g  gnc:gnc-
 collector-end g  fold g  merge g  
 collector-add g  collector-into-list g  category-by-account-report-work g  make-gnc-collector-collector g  "category-by-account-report-do-work g  + g  gnc:html-linechart-set-title! g   gnc:html-linechart-set-subtitle! g  sprintf g  _ f  %s to %s g  gnc:html-linechart-set-width! g  gnc:html-linechart-set-height! g  "gnc:html-linechart-set-row-labels! g  #gnc:html-linechart-set-major-grid?! g  $gnc:html-linechart-set-y-axis-label! g  gnc-commodity-get-mnemonic g  +gnc:html-linechart-set-row-labels-rotated?! g  length g  !gnc:html-linechart-append-column! g  gnc:not-all-zeros g  - g  "gnc:html-linechart-set-col-labels! f  Income f  Expense f  Assets f  Liabilities f  
 Net Profit f  	Net Worth g  "gnc:html-linechart-set-col-colors! f  blue f  red   f  green   g  "gnc:html-linechart-set-line-width! g   gnc:html-linechart-set-markers?! g  gnc:make-report-anchor g  category-barchart-income-uuid g  category-barchart-asset-uuid f  Use Stacked Lines f  Income Chart f  Asset Chart g  category-barchart-expense-uuid g   category-barchart-liability-uuid f  
-Expense Chart f  Liability Chart g  *gnc:html-linechart-set-button-1-line-urls! g  ,gnc:html-linechart-set-button-1-legend-urls! g  gnc:make-html-table g  gnc:html-table-set-style! f  table g  	attribute f  border f  cellspacing f  cellpadding g  gnc:html-table-set-col-headers! f  Date g  gnc:html-table-append-column! g  for-each g  gnc:html-table-set-col-style! f  td f  class f  number-cell 		  g   gnc:html-make-empty-data-warning g  gnc:report-finished g  net-renderer g  call-with-deferred-observers     g  module-export!     g  current-module     g  net-worth-linechart-uuid   f   d8b63264186b11e19038001558291366 g  gnc:define-report g  version g  name f  Net Worth Linechart g  report-guid g  	menu-path g  gnc:menuname-asset-liability g  rendererC 5 h>    ]4
+Expense Chart f  Liability Chart g  *gnc:html-linechart-set-button-1-line-urls! g  ,gnc:html-linechart-set-button-1-legend-urls! g  gnc:make-html-table g  gnc:html-table-set-style! f  table g  	attribute f  border f  cellspacing f  cellpadding g  gnc:html-table-set-col-headers! f  Date g  gnc:html-table-append-column! g  for-each g  gnc:html-table-set-col-style! f  td f  class f  number-cell 		  g   gnc:html-make-empty-data-warning g  gnc:report-finished g  net-renderer g  call-with-deferred-observers     g  module-export!     g  current-module     g  net-worth-linechart-uuid   f   d8b63264186b11e19038001558291366 g  gnc:define-report g  version g  name f  Net Worth Linechart g  report-guid g  	menu-path g  gnc:menuname-asset-liability g  rendererC 5   h>    ]4
 5 4 >  "  G   4 >  "  G  4 >  "  G  4 >  "  G  4 >  "  G  4" >  "  G  4& >  "  G  4) >  "  G  4, >  "  G  4-i.
 >  "  G  /0R12R34R56R78R9:R;<R=>R?@RABRCDREFRGHRIJRKLRMNROPRQRS24TU6VWX8YZ:[\]^<_`aa    h      ]4 5C            g  account
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 	f	
 		f	$	
-	f	 		   Cbc h       ] L $  "  445 56         g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+	f	 		   Cbc   h       ] L $  "  445 56         g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 	b		
 	d				g				g	-		g				c	 		
-   C`aa   h      ]4 5C            g  account
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+   C`aa     h      ]4 5C            g  account
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 	m			n		
-	n	 		   C     h       ]4L $  "   5 C           g  accounts
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-	h			j			k			j			i	 		   Cdef>Bgh@DijklmFHnJoLPpqNrst 3     h     ]45 4>  "  G  4	
+	n	 		   C       h       ]4L $  "   5 C           g  accounts
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+	h			j			k			j			i	 		   Cdef>Bgh@DijklmFHnJoLPpqNrst 3       h     ]45 4>  "  G  4	
 >  "  G  4
 >  "  G  4>  "  G  4 O  O 54>  "  G  4 $  "   $  "  54>  "  G  4 $  "   	 $  !"  "54>  "  G  4#
 $54>  "  G  4%&' >  "  G  4()*+
 
 	
-5	4>  "  G  4,-.54>  "  G  4/0154>  "  G  42>  "  G  C      	      g  inc-exp?
+5	4>  "  G  4,-.54>  "  G  4/0154>  "  G  42>  "  G  C            g  inc-exp?
 	 g  options	 g  
 new-option	   g  
 new-option	   g  
@@ -47,57 +47,57 @@ new-option		" g  
 new-option	0I g  
 new-option	| g  
 new-option	 g  
-new-option	  	g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+new-option	  	g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 	E
 		F			F		
 	N			P	'		N		$	R		.	S	3	0	S	7	5	R		>	U		H	V	:	M	U		V	X		`	Z		b	Z		g	X		p	^		x	`		z	a	
  	^	 	]	 	K	 	t	 	v	 	w	 	x	 	y	 	z	 	t	 	s	 	K	 	~	  	  	  	  	 			~			}		K	# 	) 	
-+ 	- 	0 	0 	3	K	J 	V 	,a 	j 	r 	| 	| 		K	 	 	 	 	 		K	 	 	 	 	 		K	 	 F	  g  nameg  options-generator CuRv0wxS4yz{|268:^<f>B@DHFNJP}~k       h      ] 6              g  date-list-item
-			  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-.	#	0	&		/	% 			   C      h      ] C       g  account
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-5	 	5	@	5	2 		   C   h      ] C       g  account
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-7	 	7	@	7	2 		   C     h      ] C       g  account
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-9	!	9	A	9	3 		   C     h      ] C       g  account
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-;	!	;	A	;	3 		   C       h      ]M L 6           g  a
-		 g  b		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
- 			 	 			   C 	 hP   f  ]
++ 	- 	0 	0 	3	K	J 	V 	,a 	j 	r 	| 	| 		K	 	 	 	 	 		K	 	 	 	 	 		K	 	 F	  g  nameg  options-generator CuRv0wxS4yz{|268:^<f>B@DHFNJP}~k h      ] 6              g  date-list-item
+			  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+.	#	0	&		/	% 			   C        h      ] C       g  account
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+5	 	5	@	5	2 		   C     h      ] C       g  account
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+7	 	7	@	7	2 		   C       h      ] C       g  account
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+9	!	9	A	9	3 		   C       h      ] C       g  account
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+;	!	;	A	;	3 		   C h      ]M L 6           g  a
+		 g  b		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+ 			 	 			   C 	   hP   d  ]
 
-4545$  "  4>  "  G  444 L LO 555C  ^      g  	collector
+4545$  "  4>  "  G  444 L LO 555C  \      g  	collector
 		N g  
 date-interval		N g  date		
-	L  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+	L  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 ?	+	@	-	@	M	
 @	0	
  		 		 	
 	  		% 	
-	. 		1 		4 		G 		I 		M@	- 		N	   C       h      ]LLO L 6            g  account
-		 g  result		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
->	$	?	& 			   Ch      ]M L 6           g  a
-		 g  b		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+	. 		1 		4 		G 		I 		M@	- 		N	   C h      ]LLO L 6            g  account
+		 g  result		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+>	$	?	& 			   C  h      ]M L 6           g  a
+		 g  b		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
  			 	 			   C 
- h`   b  ]4L >  "  G  45$  "  4>  "  G  444LL 	LO 5556      Z      g  next
-		Z g  date		Z g  list-collector			Z  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+   h`   `  ]4L >  "  G  45$  "  4>  "  G  444LL 	LO 5556      X      g  next
+		Z g  date		Z g  list-collector			Z  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 D	=	E	?	E	T	E	?	 		& 		+ 	
 	/ 		4 	
-	= 		@ 		C 		V 		X 		ZF	? 		Z	   C h(   $  ]
-45 4LLO 45 L 56        g  account
-		& g  result		& g  commodity-collector			&  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-B	$	C	A	C	&	D	7	I	=	$D	7	&D	( 		&	   C    h      ]6          g  account
-		 g  date		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-O	*	P	, 			   C    h      ]
+	= 		@ 		C 		V 		X 		ZF	? 		Z	   C   h(   "  ]
+45 4LLO 45 L 56        g  account
+		& g  result		& g  commodity-collector			&  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+B	$	C	A	C	&	D	7	I	=	$D	7	&D	( 		&	   C      h      ]6          g  account
+		 g  date		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+O	*	P	, 			   C      h      ]
 C           g  d
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-V	$ 		   C   h      ]
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+V	$ 		   C     h      ]
 C           g  d
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-X	' 		   C       h      ]L   6          g  col
-		  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+X	' 		   C h      ]L   6          g  col
+		  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 		
-					%		-				 		   C x   h8	  6  , 3 #4>  "  G  44444	 555554
+					%		-				 		   C x     h8	  4  , 3 #4>  "  G  44444	 555554
 4444	 55555444	 555
 444	 555444	 555444	 555$  "  	444	 5	55	$  "  
 	444	 5	
@@ -122,7 +122,7 @@ C           g  d
 >  "  G  4\>  "  G  $  4]$  ^"  _ ` $  4Da5"  4Db5  54]$  c"  d ` $  4De5"  4Df5  5 4g>  "  G  4h>  "  G  "   J$ k4(>  "  G  $ M4i5 4jklm
  ln
  lo	 >  "  G  4p4%4Dq5 $  0$  4DR54DS5 "  4DT54DU5 "  	$  "$  4DV5 "  
-4DW5 "  5>  "  G  4r>  "  G  $  ,4rJ>  "  G  4rJ>  "  G  "   	$  4rJ>  "  G  "   4stO u>  "  G  4(>  "  G  "   "   4(4v4* 55>  "  G  4w>   "  G  C     .      g  
+4DW5 "  5>  "  G  4r>  "  G  $  ,4rJ>  "  G  4rJ>  "  G  "   	$  4rJ>  "  G  "   4stO u>  "  G  4(>  "  G  "   "   4(4v4* 55>  "  G  4w>   "  G  C     ,      g  
 report-obj
 		3 g  inc-exp?		3 g  section		"	A g  name		"	A g  
 to-date-tp		E	3 g  section		Q	p g  name		Q	p g  from-date-tp		t	3 g  section		z  g  name		z  g  interval	 	3 g  section	   g  name	   g  report-currency	 	3 g  section	   g  name	   g  price-source	 	3 g  section	  g  name	  g  accounts		3 g  section	9 g  name		9 g  	show-sep?	9	3 g  section		Kj g  name	
@@ -133,7 +133,7 @@ to-date-tp		E	3 g  section		Q	p g  name		Q	p g  from-date-tp	
  g  name	 g  
 line-width	
 	3 g  section	# g  name	# g  y-grid	#	3 g  commodity-list	&	3 g  exchange-fn	)	3 g  
-dates-list	]	3 g  section	c g  name	c g  report-title		3 g  classified-accounts		3 g  section	 g  show-table?		3 g  document		3 g  chart		3 g  	non-zeros		3 g  assets-list	F	  g  liability-list	I	 g  net-list	L	 g  progress-range	S	 g  date-string-list	j	 g  the-acount-destination-alist	X g  account-reformat	U g  work	R g  rpt	 O g  assets	!	L g  liabilities	"I g  	data-list	^ g  	data-list	 g  	data-list	 g  urls	O| g  table	  Eg  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+dates-list	]	3 g  section	c g  name	c g  report-title		3 g  classified-accounts		3 g  section	 g  show-table?		3 g  document		3 g  chart		3 g  	non-zeros		3 g  assets-list	F	  g  liability-list	I	 g  net-list	L	 g  progress-range	S	 g  date-string-list	j	 g  the-acount-destination-alist	X g  account-reformat	U g  work	R g  rpt	 O g  assets	!	L g  liabilities	"I g  	data-list	^ g  	data-list	 g  	data-list	 g  urls	O| g  table	  Eg  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
  
 	 		 		 		" 		' 		* 		- 		9 		; 		C 		E 		E 		H 		K 		Q 		V 		Y 		\ 		h 		j 		r 		t 		t 		z 		 	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	  	 	 	 	  	 	" 	% 	1 	3 	9 	C 	 K 	P 	S 	V 	b 	d 	j 	p 	u 	x 	{ 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 		 	 	 	 	 	# 	, 	2 	; 	A 	M 	N 	U 	] 	] 	c 	h 	k 	n 	z 	| 	 	 	 	 	 	 	 	 	; 	 	 	 	 	 	 									 		 	
 $	!&	"	'	,	4	9	F(	S+	S(	V,	^-	j,	j(	r4	s5	v5	{6	!5	7	8	!7	5	9	9	:	!9	;	<	!;	9	3	=	 3	L	3	R	3	S	S	%	S		3	T	T	*T	3	U	U	&$V	.U		4W	7W	.<X	"FW		Y[	k]	
@@ -145,17 +145,17 @@ dates-list	]	3 g  section	c g  name	c g  report-title
 f	
 			
 		
-				#			#			#											 	#	 	-	0 	-		 	#	 	-	0	-		#	)	*	 .	#0	 3	8	 <	#>	 A	F	H	M	V	o	p																	!			3	  g  nameg  net-renderer CR4  h      ] 45 6          g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+				#			#			#											 	#	 	-	0 	-		 	#	 	-	0	-		#	)	*	 .	#0	 3	8	 <	#>	 A	F	H	M	V	o	p																	!			3	  g  nameg  net-renderer CR4    h      ] 45 6          g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 
  		
-   C>  "  G  Riii uu  h      ] 6        g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
+   C>  "  G  Riii uu    h      ] 6        g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
 			 		
-   C    h      ] 6              g  
+   C      h      ] 6              g  
 report-obj
-			  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm
-				  			   C6       g  m
+			  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm
+				  			   C6         g  m
 	
-	$  g  filenamef  o/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/report/standard-reports/net-linechart.scm		
+	$  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/report/standard-reports/net-linechart.scm		
 	%	
 	:	
 	O	
@@ -184,10 +184,9 @@ report-obj
 .	>	1	>
 3	A	6	A
 	E
-<	 
-<
-
+; 
+;
 <	!<
-<< < 	<<<	= =>
+<< < 	<<<	<=>
  =	>
    C6 
\ No newline at end of file
