@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0      ]  4        h
+GOOF----LE-4-2.0      ]  4        h
       ] g  guile	 	g  process-use-modules	 	 	g  srfi	g  srfi-13	 		 	
 g  gnucash	g  printf	
  	
@@ -12,13 +12,13 @@ qif-xtn:payee	ig  qif-xtn:number	jg  qif-xtn:action	kg  qif-xtn:security-n
 reconciled	}g  qif-xtn:share-price	~g  qif-xtn:num-shares	g  qif-split:amount g  qif-xtn:commission g  sell g  sellx g  shrsout g  gnc-numeric-add g  
 GNC-DENOM-LCD g  gnc-numeric-sub g  gnc-numeric-mul g  GNC-DENOM-REDUCE g  gnc-numeric-zero-p g  gnc-numeric-div g  gnc:warn f  qif-import:qif-xtn-to-gnc-xtn:  f  splits in stock transaction! g  qif-split:accounts-affected g  string? g  string=? g  buy g  buyx g  reinvint g  reinvdiv g  reinvsg g  reinvsh g  reinvmd g  reinvlg g  xaccSplitSetAmount g  xaccSplitSetValue g  gnc-numeric-neg g  cgshort g  cgshortx g  cgmid g  cgmidx g  cglong g  cglongx g  intinc g  intincx g  div g  divx g  miscinc g  miscincx g  xin g  rtrncap g  rtrncapx g  xout g  miscexp g  miscexpx g  margint g  margintx g  shrsin g  stksplit g  gnc-numeric-create g  xaccAccountGetBalance g  qif-split:matching-cleared g  xaccSplitSetParent g  xaccSplitSetAccount g  qif-split:mark g  qif-split:category g  xaccSplitSetMemo g  string-prefix? f  **VOID** g  
 xaccTransVoid f  QIF g  qif-import:mark-some-splits g  qif-split:miscx-category g  reverse g  qif-import:xtn-has-matches? g  qif-import:merge-and-mark-xtns g  
-one-to-one g  many-to-one g  one-to-many g  gnc-numeric-equal g  default-stock-acct g  default-cgshort-acct g  default-cglong-acct g  default-cgmid-acct g  default-interest-acct g  default-margin-interest-acct g  default-capital-return-acct g  default-dividend-acct g  default-equity-holding g  default-commission-acct g  qif-xtn:mark-split g  qif-import:merge-xtn-info g  qif-split:set-matching-cleared! g  qif-xtn:set-payee! g  qif-xtn:address g  qif-xtn:set-address! g  qif-xtn:set-number! g  qif-split:set-mark! g  qif-xtn:set-mark! g  !gnc:account-tree-get-transactions g  xaccTransDestroy g  xaccAccountDestroy g  qif-import:qif-to-gnc-undoC 5 h    ] 4	 >  "  G  4
+one-to-one g  many-to-one g  one-to-many g  gnc-numeric-equal g  default-stock-acct g  default-cgshort-acct g  default-cglong-acct g  default-cgmid-acct g  default-interest-acct g  default-margin-interest-acct g  default-capital-return-acct g  default-dividend-acct g  default-equity-holding g  default-commission-acct g  qif-xtn:mark-split g  qif-import:merge-xtn-info g  qif-split:set-matching-cleared! g  qif-xtn:set-payee! g  qif-xtn:address g  qif-xtn:set-address! g  qif-xtn:set-number! g  qif-split:set-mark! g  qif-xtn:set-mark! g  !gnc:account-tree-get-transactions g  xaccTransDestroy g  xaccAccountDestroy g  qif-import:qif-to-gnc-undoC 5 h    ] 4	 >  "  G  4
  >  "  G     hh     ] $   "  $  M 64  5$  $  
   " C$   C  "         g  
 allowed-types
-		e g  	currency?		e  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+		e g  	currency?		e  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 	q	
-		r			s			r			r			v			w			x		!	y		$	v		%	{		*	{		1	{	.	3	{		7	{		=	~		@		,	J			M 		T 		W 		[ 	,	e 	 		e	  g  nameg  default-account-type C !"#$%&'()*+,-./0123456789:;<=> -      h  	  , 3 45 4 5	4	5
+		r			s			r			r			v			w			x		!	y		$	v		%	{		*	{		1	{	.	3	{		7	{		=	~		@		,	J			M 		T 		W 		[ 	,	e 	 		e	  g  nameg  default-account-type C !"#$%&'()*+,-./0123456789:;<=> -h  	  , 3 45 4 5	4	5
 4	54 5HH
 H"  
 K
@@ -64,7 +64,7 @@ make-new-acct
 acc-commodity		k  g  new-acct	  g  parent-acct	  g  parent-name	  g  	acct-name	  g  last-sep	  g  default-account-type	  g  
 short-name	q< g  count	1 g  	test-name	1 g  	test-acct	. g  acc-type	 g  
 acc-commodity	 g  new-name	<n g  pinfo	/ g  acc-type	 g  
-acc-commodity	  !g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+acc-commodity	  !g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 	&
 		)			)			*			)			+			)		"	-	
 	*	)		-	/	
@@ -90,45 +90,45 @@ acc-commodity	  !g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-
 	4		5		4		7			8		8	
 	9		6		;			<	
 	e	 	
-	  g  nameg  qif-import:find-or-make-acct C<R?@ABCDEF  h       ]44 554455C           g  a
-		 g  b		  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
- 	(	 	-	 	5	 	-	 	-	 	5	 	-	 	* 				   CG3HIJ      h       ]45$  M N "   C             g  k
-		 g  v		 g  p			  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+	  g  nameg  qif-import:find-or-make-acct C<R?@ABCDEF    h       ]44 554455C           g  a
+		 g  b		  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
+ 	(	 	-	 	5	 	-	 	-	 	5	 	-	 	* 				   CG3HIJ        h       ]45$  M N "   C             g  k
+		 g  v		 g  p			  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 			
 	
 						
- 			   CJ  h       ]45$  M N "   C             g  k
-		 g  v		 g  p			  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+ 			   CJ    h       ]45$  M N "   C             g  k
+		 g  v		 g  p			  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
  		!	
 	
 !			#		"	
- 			   CJ  h       ]45$  M N "   C             g  k
-		 g  v		 g  p			  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+ 			   CJ    h       ]45$  M N "   C             g  k
+		 g  v		 g  p			  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 (		)	
 	
 )			+		*	
- 			   CEKKLM hH   e  ]	MN"  ,45$   M N MNC(  C"4 5"    ]      g  xtn
-		D g  splits		7  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+ 			   CEKKLM   hH   c  ]	MN"  ,45$   M N MNC(  C"4 5"    [      g  xtn
+		D g  splits		7  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 5	
-	6		6		7		8		8	2	8		8		:	(	:		!;	%	#;		(<	"	,<		1=	!	7=		77		87	$	D7	 		D   CF      h      ]L LO 4 56         g  qif-file
-		  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+	6		6		7		8		8	2	8		8		:	(	:		!;	%	#;		(<	"	,<		1=	!	7=		77		87	$	D7	 		D   CF        h      ]L LO 4 56         g  qif-file
+		  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 3		>	
-	4		 		   CNO       h       ]44 5L 5445L 5C       g  a
-		  g  b		   g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
-M		N		N	,	N		P		P	,	P		N	 			 	   CPQRSTUV<5  h8    ]!L $  4L 44 555"  4 54545$  "  	45MNL$  XM	
+	4		 		   CNO h       ]44 5L 5445L 5C       g  a
+		  g  b		   g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
+M		N		N	,	N		P		P	,	P		N	 			 	   CPQRSTUV<5    h8    ]!L $  4L 44 555"  4 54545$  "  	45MNL$  XM	
 $  I4	LMM>  "  G  4
 L>  "  G  $  4
->  "  G  "   "   "   "   LLLLL6"  6$  ,$  "  45$   LLLL6""$  $   LLLL6""    {      g  acctinfo
-	4 g  security	 4 g  ok-types		)4 g  equity?		44 g  t		?	Y g  stock?		Y4  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+>  "  G  "   "   "   "   LLLLL6"  6$  ,$  "  45$   LLLL6""$  $   LLLL6""    y      g  acctinfo
+	4 g  security	 4 g  ok-types		)4 g  equity?		44 g  t		?	Y g  stock?		Y4  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 U		W			X		Y	 	Z	!	Y	 	X		 V			#[		)V			,\		4V			7]		?]		N^		YV			^		`		f		k		l		q		r			{
 	- 		 	 	 
 	 
 	 
 	 m	 a	 g	  h	$ g	i	a	a	,b	 (	4   CWSTUVXYG03Z[\KSTUVX]^_`a 
- h     ]	M	N	L$  XM		
+   h     ]	M	N	L$  XM		
 $  I4LM	M>  "  G  4L>  "  G  $  4>  "  G  "   "   "   4 5$  C445 54	>  "  G  4
 L>  "  G  4 L LLLLLL>	  "  G  6          g  xtn
-	  g  gnc-xtn	|   g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+	  g  gnc-xtn	|   g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 	
 					
 											"
@@ -136,13 +136,13 @@ $  I4LM	M>  "  G  4L>  "  G  $  4>  "  G  "   "   "   
 		L
 		Q
 		f		p		s		v	 	|		|			 	 	 	 	    CF 
-hX   !  ]L$  +4L4454 55>  "  G  "    LLLLLLLLL O 
-4	 56       g  qif-file
-		W  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+  hX     ]L$  +4L4454 55>  "  G  "    LLLLLLLLL O 
+4	 56       g  qif-file
+		W  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 							
 		*		9		<		9		J		5	"	*	'	
 	O	
-	W		 		W   C !   hp    ]`45  445 54	545 4445 5L 5HH4	L
+	W		 		W   C !     hp    ]`45  445 54	545 4445 5L 5HH4	L
 5
 H
 H	L$  4L4
@@ -151,12 +151,12 @@ $  I4LJ	J>  "  G  4L>  "  G  $  4>  "  G  "   "   "   
 5$  "  4
 >  "  G  (  "  
 "aJJ
-"S"   4 	LLLLLO 	>  "  G  L$  4L>  "  G  "   C         g  old-root
+"S"   4 	LLLLLO 	>  "  G  L$  4L>  "  G  "   C        g  old-root
 	n g  new-root	n g  
 gnc-acct-hash		n g  sep		#n g  default-currency		8n g  sorted-accounts-list		;n g  
 markable-xtns		>n g  sorted-qif-files-list		In g  
 work-to-do		Ln g  	work-done			On g  xtn	
-t g  rest	t  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+t g  rest	t  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
  		 		 		
  		
  	(	 		 		 		 		 		# 		& 	
@@ -179,34 +179,34 @@ work-to-do		Ln g  	work-done			On g  xtn
 x	y	!x	
 &	T	U	
  T	n
-  g  nameg  private-convert CbcVcd  h      - 1 3  C           g  key
-			 g  args			  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+  g  nameg  private-convert CbcVcd    h      - 1 3  C           g  key
+			 g  args			  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 	0 			
-   C  h      ] L 6           g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+   C    h      ] L 6           g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 	
 				 		
-   C      h      - 1 3 C            g  key
-			 g  args			  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+   Ch      - 1 3 C            g  key
+			 g  args			  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 	
  			
-   C  h      ] L O 6              g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+   C    h      ] L O 6              g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 			
 		 		
-   C     h8     , 3 	O  Q O 6           g  qif-files-list
-		3 g  qif-acct-map		3 g  qif-cat-map			3 g  qif-memo-map			3 g  	stock-map			3 g  default-currency-name			3 g  transaction-status-pref			3 g  progress-dialog			3 g  private-convert			3  	g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+   C       h8     , 3 	O  Q O 6           g  qif-files-list
+		3 g  qif-acct-map		3 g  qif-cat-map			3 g  qif-memo-map			3 g  	stock-map			3 g  default-currency-name			3 g  transaction-status-pref			3 g  progress-dialog			3 g  private-convert			3  	g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
  
-	3	 		3	  g  nameg  qif-import:qif-to-gnc CeRMfghijklmnopqrs3tduvwxyz{|}~EKfwgxLEz{|     hX    ]I4 5$  C445 54 5L	$  4 5"  4 5HHHHJ$  "  45 KM J	4	
+	3	 		3	  g  nameg  qif-import:qif-to-gnc CeRMfghijklmnopqrs3tduvwxyz{|}~EKfwgxLEz{|       hX    ]I4 5$  C445 54 5L	$  4 5"  4 5HHHHJ$  "  45 KM J	4	
 	5	N 4
 J45>  "  G  4J45>  "  G  $  4
 >  "  G  "   45$  "  4 5$  4L5K"  45$  4L5$  k4L5$  4L5$  "  	4LL5"  $  "  +4M5$  4M5$  "  	4LM5"  "  +45$  45$  "  	4L5"  KJ$  "  4L5K"  4L5K4J5K4LJ5K4 5&  4c>  "  G  "   &  4y>  "  G  "   4J>  "  G  L6           g  	qif-split
 	S g  
 gnc-far-split	<S g  
 far-acct-info		<S g  
-far-acct-name		<S g  far-acct		<S g  	split-amt		<S g  memo		<S g  cat		<S g  a		_	u g  b			_	u g  n		~  g  n	   g  t	F g  cleared	7  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+far-acct-name		<S g  far-acct		<S g  	split-amt		<S g  memo		<S g  cat		<S g  a		_	u g  b			_	u g  n		~  g  n	   g  t	F g  cleared	7  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 				
 	
 		&		'		&		"	)		*		6 		<		P"		U"	7	["	'	_&	*	d		w&		x'		~'	4 	 '	 (	 (	5 	 (	 *	 *	 /	 /	- /	 /	 0	 -	 1	) 1	4	4	(
-4	-	?	"?	?	@	(&@	#'A	--A	A/A	-3@	#9B	(F@	UC	(_C	#`D	-fD	@hD	-lC	#rE	(F	$F	G	)G	8G	)F	H	$>	I	J	-J	5	)5	L	'L	M	"M	P	"P	Q	Q	R	S	S	T	8W	SX	 U	S   C `  h    , 	3 +4 5445 545 4 54 54 54 54	 54
+4	-	?	"?	?	@	(&@	#'A	--A	A/A	-3@	#9B	(F@	UC	(_C	#`D	-fD	@hD	-lC	#rE	(F	$F	G	)G	8G	)F	H	$>	I	J	-J	5	)5	L	'L	M	"M	P	"P	Q	Q	R	S	S	T	8W	SX	 U	S   C `    h    , 	3 +4 5445 545 4 54 54 54 54	 54
  54 54 5HHH
 HH
 	$  4
@@ -248,7 +248,7 @@ J>  "  G  4X&>  "  G  4Y&J">  "  G  J%$  ,4XJ%>  "  G 
 J>  "  G  4<
 J>  "  G  4X
 >  "  G  4Y
-J>  "  G  425$  )4\]5$  4^_>  "  G  "   "   C            g  qif-xtn
+J>  "  G  425$  )4\]5$  4^_>  "  G  "   "   C            g  qif-xtn
 	 g  qif-file	 g  gnc-xtn		 g  
 gnc-acct-hash		 g  qif-acct-map		 g  qif-cat-map		 g  qif-memo-map		 g  transaction-status-pref		 g  progress-dialog		 g  splits			X g  gnc-near-split	
 	X g  near-split-total		X g  near-acct-info		X g  near-acct-name	
@@ -280,7 +280,7 @@ gnc-far-split	&%
  g  a	' g  b	( g  a	' g  b	( g  t	'e g  t	' g  t	' g  t	'  g  n	'GS g  n	'gs g  n	' g  n	'
  g  a	'e{ g  b	(e{ g  
 splitratio	'{ g  	in-shares	( g  
-out-shares	) g  n	* g  cleared	'		T g  t	'	c	} g  commission-acct-info	'	}	 g  commission-acct-name	(		  =g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+out-shares	) g  n	* g  cleared	'		T g  t	'	c	} g  commission-acct-info	'	}	 g  commission-acct-name	(		  =g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 
 						)					 		'		.		5		<		D		K		R		X		|		}	 	( 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 				!	$	++	&-	/	5	;	?	$@	E	I	
 J	b	} 	 							e	e	f	e	h	h	/h	*h	e	q	e	s	s	/%s	%e	-u	
@@ -376,17 +376,17 @@ q	
 \	
 f	g 	
 k 	o 	
-s	t!	z!	!	(			  g  nameg  qif-import:qif-xtn-to-gnc-xtn C`RLM   h`     ]
+s	t!	z!	!	(			  g  nameg  qif-import:qif-xtn-to-gnc-xtn C`RLM     h`     ]
 "  MJ(  "  34J5$  "  4J5$  4J 5K"  JKJ(  CJH"4 5H"      g  xtn
-		` g  candidate-xtns		` g  splits-left			S  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+		` g  candidate-xtns		` g  splits-left			S  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 -
-	.		4		5		5	&	5		5		"6		'6	1	)6		-5		.8		:7		A:		C:		I<		S=		S.		T.		`.	 		`	  g  nameg  qif-import:mark-matching-xtns CYRmkjngKL     h`   R  ]"  	 M N C4 5$  @4M4 55$  * MNM4 54
-5NC""  J      g  s
-		^ g  a	<	R g  b		<	R  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+	.		4		5		5	&	5		5		"6		'6	1	)6		-5		.8		:7		A:		C:		I<		S=		S.		T.		`.	 		`	  g  nameg  qif-import:mark-matching-xtns CYRmkjngKL       h`   P  ]"  	 M N C4 5$  @4M4 55$  * MNM4 54
+5NC""  H      g  s
+		^ g  a	<	R g  b		<	R  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 e		m		
 l		f	
 	f		f	
-	g		 g	.	(g		,f		1j		3i		6k	9	<k	&	AH		Tk	 		^   CX !  h  Z  ]s HH454545HH45	45
+	g		 g	.	(g		,f		1j		3i		6k	9	<k	&	AH		Tk	 		^   CX !    h  X  ]s HH454545HH45	45
 HHH
 H	$ 845KK K
 $ 
@@ -408,12 +408,12 @@ J
 $   4JJ
 >  "  G  K"   "   J$  "  $  	""  "wJ
 $  .J
-$  "  $   C $  JCC C       R      g  splits
+$  "  $   C $  JCC C       P      g  splits
 	 g  xtn	 g  candidate-xtns		 g  split		 g  near-acct-name		 g  
 far-acct-name		 g  date		 g  n			) g  amount		) g  group-amount		, g  
 security-name			5 g  action	
 	> g  different-acct-splits		A g  same-acct-splits		D g  how	
-	G g  done		J g  	qif-accts		[ g  n	   g  n	+ g  n	my g  xtns	Y g  key	j  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+	G g  done		J g  	qif-accts		[ g  n	   g  n	+ g  n	my g  xtns	Y g  key	j  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 F
 	L		G		O		G		P		P		 G		)G		/R		5G		8S		>G		AU	 	AG		DV		DG		RZ		Sv		[u		`w		bw	
 	ex		hx	
@@ -428,7 +428,7 @@ security-name			5 g  action
 			"		
 			,					/					2%	0	>	
 F	G	H	L	O	U	
-Y	g	j	j				 b		  g  nameg  qif-import:mark-some-splits CRgmELkjM   hP  O  ]]45 4 5$  a$  U45	&  C45	&  1$  !$  "  "  "  "  "  "  HHH$ " 	
+Y	g	j	j				 b		  g  nameg  qif-import:mark-some-splits CRgmELkjM     hP  M  ]]45 4 5$  a$  U45	&  C45	&  1$  !$  "  "  "  "  "  "  HHH$ " 	
 4
 5$ Q45$ B44
 55$ ,4
@@ -452,17 +452,17 @@ JKJJ4
 
  K"  ""  "
 "   "   "   J$  "  	$  			""  
-4 5	"nJ$  "  	4J5$  JK"   "   JC    G      g  xtn
+4 5	"nJ$  "  	4J5$  JK"   "   JC    E      g  xtn
 	L g  	acct-name	L g  date		L g  amount		L g  	group-amt		L g  	self-date			~ g  same-acct-splits		~L g  this-group-amt		~L g  how		~L g  date-matches		~L g  splits-left		  g  split	
   g  this-amt	  g  	stock-xtn	  g  action	
-  g  n	Q] g  a	 g  b	  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+  g  n	Q] g  a	 g  b	  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 
 					
 											 		!		-		.		:		=		@	#	A		E		H		L	$	N		R		U		Z	%	]		~	 	 	
  	 	 	 	 	 	 	 	! 	 	 	" 	# 	  	 	 	 	Q	*T	_	l	x	z	"	.		-						%		"	/			# 						
 	("	
 (	.	:	
-<	?	A	 P	L	  g  nameg  qif-import:xtn-has-matches? CRkjnM 3     h    ]2454545HHH$ H$  "  $  "  $  "  $  "  u$  "  g	$  "  Y
+<	?	A	 P	L	  g  nameg  qif-import:xtn-has-matches? CRkjnM 3       h    ]2454545HHH$ H$  "  $  "  $  "  $  "  u$  "  g	$  "  Y
 $  "  K$  "  =$  "  /
 $  "  !$  "  $  "  $  45K" 7$  "  $  "  u$  "  g$  "  Y$  "  K$  "  =$  "  /$  "  !$  "  $  "  $  K"  $  "  K$  "  =$  "  / $  "  !!$  "  "$  "  #$  4$4%55K"  *&$  "  '$  4(4%55K"   $  "  $  K" $  "  Y$  "  K$  "  =&$  "  /$  "  !'$  "  $  "  $  4$4%55K" $  45K" $  "  !$  "  
 $  "  $  4)5K" >$  "  $  "  $  4*5K" 
@@ -471,9 +471,9 @@ $  4+5K"  $  "  !$  "  $  4,5K"  $  "  
 4-5K"  ~$  "  "$  4.5K"  X$  "  $  "  	$  4/5K"  $$  "  $  
 405K"   415$  
 425K"   "  
-K4$ 5KJJJ C     	      g  split
+K4$ 5KJJJ C           g  split
 	 g  xtn	 g  near-acct-name		 g  
-far-acct-name		 g  commission-acct-name		 g  security		 g  action		 g  	from-acct		  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+far-acct-name		 g  commission-acct-name		 g  security		 g  action		 g  	from-acct		  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 
 			
 				 		,		5	
@@ -509,14 +509,14 @@ far-acct-name		 g  commission-acct-name		 g  security		 g
 YG	cG	
 dI	lH	x	
 y		
-K	 C		  g  nameg  qif-split:accounts-affected CRjkKo       h      ] 4L 56        g  s
-		  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+K	 C		  g  nameg  qif-split:accounts-affected CRjkKo h      ] 4L 56        g  s
+		  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 e		f	-	f	
- 		   Co      h      ] 4L 56        g  s
-		  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+ 		   Co        h      ] 4L 56        g  s
+		  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 o		q	
 	p	
- 		   CEMo       hP    ]<4 5454 545
+ 		   CEMo hP    ]<4 5454 545
 		$  54 >  "  G  4 >  "  G   O 
 6	$  64
 >  "  G  4 >  "  G  	O 64
@@ -542,7 +542,7 @@ far-acct-name		 g  commission-acct-name		 g  security		 g
 	J g  splits	J g  	other-xtn		J g  how		J g  action		'J g  o-action		'J g  security		'J g  
 o-security		'J g  split		'J g  
 match-type			'J g  match-splits	
-	'J  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+	'J  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 T
 	V		
 W		X		Y		!Z		$[		'\		'V		>]		?b		Sc		sd		|]		}l	 l	% l	 m	 n	 {	 {	 {	 |	 |	 |	 {		 v	 }	 ~	 	 	#										"v	#	*	-/	8	P	X	^		tv	u					
@@ -551,34 +551,34 @@ match-type			'J g  match-splits
 	
 		
 v						'				)	1		7		F					
- 	 				*		6	>	 Q	J	  g  nameg  qif-import:merge-and-mark-xtns CRhi      h     ]4 5$  ,45$  "  44 5>  "  G  "   4 5$  ,45$  "  44 5>  "  G  "   4 5$  45$  C4 56C       g  from-xtn
-	  g  to-xtn	   g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+ 	 				*		6	>	 Q	J	  g  nameg  qif-import:merge-and-mark-xtns CRhi        h     ]4 5$  ,45$  "  44 5>  "  G  "   4 5$  ,45$  "  44 5>  "  G  "   4 5$  45$  C4 56C       g  from-xtn
+	  g  to-xtn	   g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 
 			
-								"	!	-		:		D		E		O		T		Y	#	d		q		{		|	 	 	" 	 	 	  g  nameg  qif-import:merge-xtn-info CRM h`     ]4>  "  G  H"  '45$  (  "  "K"  
+								"	!	-		:		D		E		O		T		Y	#	d		q		{		|	 	 	" 	 	 	  g  nameg  qif-import:merge-xtn-info CRM   h`     ]4>  "  G  H"  '45$  (  "  "K"  
 4 5"J$   6C       g  xtn
 		_ g  split		_ g  
-all-marked			_ g  splits			C  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+all-marked			_ g  splits			C  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 
 									"		$		(		+		/	
 	6		<		?	
-	C		D		P		V		]	 		_	  g  nameg  qif-xtn:mark-split CRK    h      ] 6       g  elt
-		  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
-			 		   C         h@     ]	 $  54 54>  "  G  4 >  "  G   6C       g  root
-		? g  txns		=  g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm
+	C		D		P		V		]	 		_	  g  nameg  qif-xtn:mark-split CRK      h      ] 6       g  elt
+		  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
+			 		   C   h@     ]	 $  54 54>  "  G  4 >  "  G   6C       g  root
+		? g  txns		=  g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm
 
-										&		=	 		?  g  nameg  qif-import:qif-to-gnc-undo CRC           g  filenamef  j/usr/src/ports/gnucash/gnucash-2.6.19-1.x86_64/src/gnucash-2.6.19/src/import-export/qif-imp/qif-to-gnc.scm		
+										&		=	 		?  g  nameg  qif-import:qif-to-gnc-undo CRC             g  filenamef  h/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/import-export/qif-imp/qif-to-gnc.scm		
 		
 	&
-/ 
+/| 
 U
 W-
 bF
 j
 s
-~T
-      s
-      
+}T
+      I
+      g
       
  	      
    C6 
\ No newline at end of file
